@@ -6,7 +6,8 @@ Information about release and authors
 ===============================================================
 """
 
-__author__ = """Diana Zaiceva <zaiceva@cs.karelia.ru>,
+__author__ = """
+                Diana Zaiceva <zaiceva@cs.karelia.ru>,
                 Mezhenin Artoym <mezhenin@cs.karelia.ru>,
                 Alexander Sannikov <sannikov@cs.karelia.ru>,
                 Kirill Germanov <kgermano@cs.karelia.ru>
