@@ -120,7 +120,7 @@ class HomePage(QtGui.QWidget):
             self.upic = QtGui.QImage(path_ava)
             self.image_label.setPixmap(QtGui.QPixmap.fromImage(self.upic))
         else:
-            self.image_label.setText("Photo")
+             self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/user.png")))
 
 
 
@@ -144,9 +144,12 @@ class HomePage(QtGui.QWidget):
         self.acc_combo_box = self.create_list_acc(def_acc)
         path_ava = def_acc.path_to_ava
         # if user haven't userpic on service, it isn't added. 
+
         if path_ava:
             self.upic = QtGui.QImage(path_ava)
             self.image_label.setPixmap(QtGui.QPixmap.fromImage(self.upic))
+        else:
+            self.image_label.setPixmap(QtGui.QPixmap.fromImage(QtGui.QImage("../data/user.png")))
 
         vbox1.addWidget(self.image_label)
         vbox1.addWidget(self.acc_combo_box)
@@ -163,17 +166,26 @@ class HomePage(QtGui.QWidget):
         @param
         @return
         """
+
         add_post_button = QtGui.QPushButton(self.tr("&Add post"), self)
         my_post_button = QtGui.QPushButton(self.tr("&My posts"), self)
+        friends_posts_btn = QtGui.QPushButton(self.tr("&Friends posts"), self)
+
         add_post_button.setIcon(QtGui.QIcon("../data/add_post.png"))
         my_post_button.setIcon(QtGui.QIcon("../data/tree2.png"))
+        friends_posts_btn.setIcon(QtGui.QIcon("../data/tree2.png"))
+
         hbox = QtGui.QHBoxLayout()
         hbox.addWidget(add_post_button, -1, QtCore.Qt.AlignCenter)
         hbox.addWidget(my_post_button, -1, QtCore.Qt.AlignCenter)
+        hbox.addWidget(friends_posts_btn, -1, QtCore.Qt.AlignCenter)
+
         self.connect(add_post_button, QtCore.SIGNAL("clicked()"),
                      self.mainwindow.add_post)
         self.connect(my_post_button, QtCore.SIGNAL("clicked()"),
                      self.mainwindow.list_my_posts)
+        self.connect(friends_posts_btn, QtCore.SIGNAL("clicked()"),
+                     self.mainwindow.list_friends_posts)
         return hbox
 
 
