@@ -16,7 +16,7 @@ from MainWindow import main_window
 from ToolbarWindow import ToolbarWindow
 
 from ldm.Message import Message
-from ldm.Profile import main_prof
+#from ldm.Profile import main_prof
 from ldm.Account import Account
 
 from ScriboExc import WarningExc
@@ -34,7 +34,7 @@ class ViewMessage(ToolbarWindow):
     @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
     @todo  all hanglers
     """
-    def __init__(self, parent=None, msg="default"):
+    def __init__(self, parent, list, msg):
         """ 
         initialization viewing window
         @return
@@ -44,8 +44,9 @@ class ViewMessage(ToolbarWindow):
         msg.read = True
         self.create_actions()
         toolbar = self.create_toolbar()
-        self.list = main_prof.get_posts()
-        self.vbox = QtGui.QVBoxLayout()
+        sec_toolbar = self.create_toolbar_second()
+        self.list = list
+        self.hbox = QtGui.QHBoxLayout()
 
         key = self.list.index(self.msg)
         if key < 1:
@@ -56,9 +57,10 @@ class ViewMessage(ToolbarWindow):
         self.view_mes_widget = QWebView(self)
         self.view_mes(msg)
         self.view_mes_widget.show()
-        self.vbox.addWidget(toolbar)
-        self.vbox.addWidget(self.view_mes_widget)
-        self.setLayout(self.vbox)
+        self.hbox.addWidget(toolbar)
+        self.hbox.addWidget(self.view_mes_widget)
+        self.hbox.addWidget(sec_toolbar)
+        self.setLayout(self.hbox)
 
 
     def view_mes(self, msg):
@@ -82,7 +84,7 @@ class ViewMessage(ToolbarWindow):
             author = ""
 
         if not title:
-            title = ""
+            title = "no subject"
         if not tags:
             tags = ""
         if not text:
@@ -101,7 +103,8 @@ class ViewMessage(ToolbarWindow):
         title = self.text_escape(title)
         tags = self.text_escape(tags)
         text = self.text_br(text)
-
+        """
+        #version with comment
         self.view_mes_widget.setHtml("<head><meta http-equiv=\"Content-Type\" \
                     content=\"text/html; charset=utf-8\" /> \
                     </head> <h3><a href = \"scribo://parent\">\
@@ -112,6 +115,15 @@ class ViewMessage(ToolbarWindow):
                     "<br/><b> Date: </b>" + date + "<br/><b> Tags: </b>"
                     + tags + "<br/>" "<b> Text:\
                     </b><br />" + text + "<br/>")
+        """
+        self.view_mes_widget.setHtml("<head><meta http-equiv=\"Content-Type\" \
+                    content=\"text/html; charset=utf-8\" /> \
+                    </head><h3><font color=\"green\">\
+                    Post:</font> </h3><b>Title: </b>" + title +
+                    "<br/> <b> Author: </b>" + author +
+                    "<br/><b> Date: </b>" + date + "<br/><b> Tags: </b>"
+                    + tags + "<br/>" "<b> Text:\
+                    </b><br />" + text + "<br/>")
 
         del(title)
         del(text)
@@ -139,28 +151,30 @@ class ViewMessage(ToolbarWindow):
 
     def text_br(self, text):
         str = QtCore.QString(text)
-        str.replace("/n", "<br />")
+        str.replace("\n", "<br />")
         return str
 
+
     def create_toolbar(self):
         """
-        create toolbar for window
+        create profile for "add profile" window
         @return
         """
-        file_tool_bar = QtGui.QToolBar("", self)
-        file_tool_bar.setIconSize(QtCore.QSize(64, 64))
-        file_tool_bar.addAction(self.back_act)
-        file_tool_bar.addAction(self.home_act)
-        #file_tool_bar.addAction(self.refresh_act)
-        file_tool_bar.addAction(self.up_act)
-        file_tool_bar.addAction(self.down_act)
+        file_tool_bar = super(ViewMessage, self).create_toolbar()
         file_tool_bar.addAction(self.edit_act)
         if not self.msg.is_editable():
             self.edit_act.setDisabled(True)
-        #file_tool_bar.addAction(self.tree_act)
-
         return file_tool_bar
 
+    def create_toolbar_second(self):
+        """
+        create profile for "add profile" window
+        @return
+        """
+        second_tool_bar = super(ViewMessage, self).create_toolbar_second()
+        second_tool_bar.addAction(self.up_act)
+        second_tool_bar.addAction(self.down_act)
+        return second_tool_bar
 
     def create_actions(self):
         """
